try:
    import tkinter
except:
    import Tkinter as tkinter

class TimedDialog:
    def __init__(self):
        pass

    def selected(self, value):
        self.response = value
        self.top.destroy()

    def button_input(self, title, message, buttons, default, timeout=None, dimensions=None):
        self.response = default
        self.top = tkinter.Tk()
        self.top.title(title)

        if dimensions is not None:
            self.top.minsize(width=dimensions[0], height=dimensions[1])
            self.top.maxsize(width=dimensions[0], height=dimensions[1])

        labelString = tkinter.StringVar()
        labelString.set(message)
        label = tkinter.Label(self.top, textvariable=labelString, relief=tkinter.RAISED)
        label.pack(ipadx=100, ipady=10)

        for key in buttons.keys():
            button = tkinter.Button(self.top, text=buttons[key], command=lambda key=key: self.selected(key))
            button.pack(fill='both', pady=5, padx=10)

        if timeout != None:
            self.top.after(timeout, lambda: self.top.destroy())

        self.top.mainloop()
        return self.response



from distutils.core import setup

setup(
    name = 'py-timed-dialog',
    packages = ['ptd'],
    version = '0.0.1',
    description = 'A Python module to create dialog boxes that self destruct after a set period of time',
    author = 'Rohith PR',
    author_email = 'praroh2@gmail.com',
    url = 'https://github.com/rohithpr/py-timed-dialog',
    download_url = 'https://github.com/rohithpr/py-timed-dialog/tarball/0.0.1',
    keywords = ['gui', 'dialog box', 'timeout dialog box'],
    classifiers = [
        'Intended Audience :: Developers',
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development :: Libraries :: Tcl Extensions',
    ],
)
